@@ -1871,4 +1871,23 @@
 
 
   </enforce-rules>
+
+  <preferences>
+   <prefer tags="vblex.pii.p3.sg"/>
+   <prefer tags="vbser.pii.p3.sg"/>
+   <prefer tags="vbhaver.pii.p3.sg"/>
+   <prefer tags="vbmod.pii.p3.sg"/>
+   <prefer tags="vblex.prs.p3.sg"/>
+   <prefer tags="vbser.prs.p3.sg"/>
+   <prefer tags="vbhaver.prs.p3.sg"/>
+   <prefer tags="vbmod.prs.p3.sg"/>
+   <prefer tags="vblex.cni.p3.sg"/>
+   <prefer tags="vbser.cni.p3.sg"/>
+   <prefer tags="vbhaver.cni.p3.sg"/>
+   <prefer tags="vbmod.cni.p3.sg"/>
+   <prefer tags="vblex.pis.p3.sg"/>
+   <prefer tags="vbser.pis.p3.sg"/>
+   <prefer tags="vbhaver.pis.p3.sg"/>
+   <prefer tags="vbmod.pis.p3.sg"/>
+  </preferences>
 </tagger>
